@@ -1,5 +1,5 @@
+from django import forms
 from django.contrib import admin
-from django.contrib.admin import widgets
 from django.utils.translation import gettext_lazy as _
 
 from solo.admin import SingletonModelAdmin
@@ -28,13 +28,16 @@ class CamundaConfigAdmin(SingletonModelAdmin):
 
 
 class CamundaFieldsMixin:
+    def _is_enabled(self, request) -> bool:
+        # cache on the request, as model admin instances persist across requests
+        if not hasattr(request, "_camunda_config"):
+            request._camunda_config = CamundaConfig.get_solo()
+        return request._camunda_config.enabled
+
     def formfield_for_dbfield(self, db_field, request, **kwargs):
-        if isinstance(db_field, ProcessDefinitionField):
+        if self._is_enabled(request) and isinstance(db_field, ProcessDefinitionField):
             kwargs.update(
-                {
-                    "widget": widgets.AdminRadioSelect(),
-                    "choices": get_process_definition_choices(),
-                }
+                {"widget": forms.Select, "choices": get_process_definition_choices()}
             )
 
         return super().formfield_for_dbfield(db_field, request, **kwargs)
